@@ -78,7 +78,9 @@ void AtomTopLevel::createMenu()
 {
     // Game
     KStandardGameAction::restart(m_gameWid, SLOT(restartLevel()), actionCollection());
-    KStandardGameAction::highscores(m_gameWid, SLOT(showHighscores()), actionCollection());
+    // FIXME: comment this until highscore dialog will be implemented.
+    // (katomic needs spesial one)
+//    KStandardGameAction::highscores(m_gameWid, SLOT(showHighscores()), actionCollection());
     KStandardGameAction::load(m_gameWid, SLOT(loadGame()), actionCollection());
     KStandardGameAction::save(m_gameWid, SLOT(saveGame()), actionCollection());
     KStandardGameAction::quit(this, SLOT(close()), actionCollection());
