@@ -18,7 +18,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgfibschat.cpp 695059 2007-08-01 09:44:53Z dimsuz $
+  $Id: kbgfibschat.cpp 721729 2007-10-05 23:25:56Z apaku $
 
 */
 
@@ -62,6 +62,7 @@
 #include <kiconloader.h>
 #include <kglobal.h>
 #include <kicon.h>
+#include <kconfiggroup.h>
 
 #include "clip.h"
 #include "version.h"
@@ -227,7 +228,7 @@ KBgChat::KBgChat(QWidget *parent)
     /*
      * some eye candy :)
      */
-    setWindowIcon(qApp->windowIcon().pixmap(IconSize(K3Icon::Small),IconSize(K3Icon::Small)));
+    setWindowIcon(qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
     setWindowTitle(i18n("Chat Window"));
 
     this->setWhatsThis( i18n("This is the chat window.\n\n"
