@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbggame.h 626506 2007-01-23 14:46:02Z dfaure $
+  $Id: kbggame.h 661774 2007-05-06 15:10:34Z milliams $
 
 */
 
@@ -33,7 +33,7 @@ class KPlayer;
  *
  *
  */
-class KDE_EXPORT KBgGame : public KGame
+class KBgGame : public KGame
 {
     Q_OBJECT
 
@@ -41,7 +41,7 @@ public:
 
     enum MsgID {Text, Cmd, MaxMsg};
 
-    KBgGame(int cookie = 42, QObject *parent = 0);
+    explicit KBgGame(int cookie = 42, QObject *parent = 0);
 
 protected:
 
