@@ -17,12 +17,12 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgoffline.cpp 632863 2007-02-12 15:11:00Z ilic $
+  $Id: kbgoffline.cpp 661443 2007-05-05 15:24:28Z milliams $
 
 */
 
-#include "kbgoffline.moc"
 #include "kbgoffline.h"
+#include "kbgoffline.moc"
 #include "kbgofflinecalc.h"
 
 #include <QLayout>
@@ -42,7 +42,7 @@
 #include <kstandardaction.h>
 #include <kconfig.h>
 #include <klocale.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <krandomsequence.h>
@@ -124,7 +124,7 @@ public:
 /*
  * Constructor
  */
-KBgEngineOffline::KBgEngineOffline(KMainWindow *parent, QMenu *pmenu)
+KBgEngineOffline::KBgEngineOffline(KXmlGuiWindow *parent, QMenu *pmenu)
     : KBgEngine(parent, pmenu)
 {
     d = new KBgEngineOfflinePrivate();
@@ -311,16 +311,15 @@ void KBgEngineOffline::setupCancel()
  */
 void KBgEngineOffline::readConfig()
 {
-    KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup("offline engine");
+    KConfigGroup config(KGlobal::config(), "offline engine");
 
-    d->mName[0] = config->readEntry("player-one", i18n("South")); // same as above
-    d->mName[1] = config->readEntry("player-two", i18n("North")); // same as above
-    d->mComputer[0] = config->readEntry("player-one-computer", false);
-    d->mComputer[1] = config->readEntry("player-two-computer", true );
-    d->mMatchTo = (config->readEntry("match-to") ).toInt();
+    d->mName[0] = config.readEntry("player-one", i18n("South")); // same as above
+    d->mName[1] = config.readEntry("player-two", i18n("North")); // same as above
+    d->mComputer[0] = config.readEntry("player-one-computer", false);
+    d->mComputer[1] = config.readEntry("player-two-computer", true );
+    d->mMatchTo = (config.readEntry("match-to") ).toInt();
 
-    cl = config->readEntry("timer", 2500);
+    cl = config.readEntry("timer", 2500);
 }
 
 /*
@@ -328,15 +327,14 @@ void KBgEngineOffline::readConfig()
  */
 void KBgEngineOffline::saveConfig()
 {
-    KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup("offline engine");
+    KConfigGroup config(KGlobal::config(), "offline engine");
 
-    config->writeEntry("player-one", d->mName[0]);
-    config->writeEntry("player-two", d->mName[1]);
-    config->writeEntry("player-one-computer", d->mComputer[0]);
-    config->writeEntry("player-two-computer", d->mComputer[1]);
-    config->writeEntry("match-to", QString::number( d->mMatchTo ));
-    config->writeEntry("timer",      cl);
+    config.writeEntry("player-one", d->mName[0]);
+    config.writeEntry("player-two", d->mName[1]);
+    config.writeEntry("player-one-computer", d->mComputer[0]);
+    config.writeEntry("player-two-computer", d->mComputer[1]);
+    config.writeEntry("match-to", QString::number( d->mMatchTo ));
+    config.writeEntry("timer",      cl);
 }
 
 
@@ -356,7 +354,7 @@ void KBgEngineOffline::newGame()
     if (d->mGameFlag && (KMessageBox::warningYesNo((QWidget *)parent(),
                                                    i18n("A game is currently in progress."
                                                         "Starting a new one will terminate it."),
-                                                   QString::null, KGuiItem(i18n("Start New Game")),
+                                                   QString(), KGuiItem(i18n("Start New Game")),
                                                    KGuiItem(i18n("Continue Old Game")))
                          == KMessageBox::No))
         return;
@@ -369,7 +367,7 @@ void KBgEngineOffline::newGame()
     /*
      * Get player's names - user can still cancel
      */
-    if ( d->mGame[0].points(US) == 0 && d->mGame[0].points(THEM) == 0 ) { 
+    if ( d->mGame[0].points(US) == 0 && d->mGame[0].points(THEM) == 0 ) {
    	if (!queryPlayerName(US) || !queryPlayerName(THEM))
        	return;
     }
@@ -661,7 +659,7 @@ void KBgEngineOffline::rollDice(const int w)
         rollDiceBackend(w, getRandom(), getRandom());
         return;
     }
-    emit infoText(i18n("It's not your turn to roll!"));
+    emit infoText(i18n("It is not your turn to roll!"));
 }
 
 /*
@@ -828,7 +826,7 @@ bool KBgEngineOffline::queryClose()
 
     switch (KMessageBox::warningContinueCancel((QWidget *)parent(),
                                       i18n("In the middle of a game. "
-                                           "Really quit?"), QString::null, KStandardGuiItem::quit())) {
+                                           "Really quit?"), QString(), KStandardGuiItem::quit())) {
     case KMessageBox::Continue :
         return true;
     case KMessageBox::Cancel :
