@@ -16,7 +16,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbg.cpp 702587 2007-08-20 21:37:44Z thiago $
+  $Id: kbg.cpp 712975 2007-09-15 21:54:19Z aacid $
 
 */
 
@@ -133,17 +133,6 @@ KBg::KBg()
 	endAction->setEnabled(false);
 
   
-  
-  
-	QStringList list;
-	for (int i = 0; i < MaxEngine; i++)
-		list.append(engineString[i]);
-	engineSet = new KSelectAction(i18n("&Engine"), this);
-	//actionCollection()->addAction("move_engine", engineSet);
-	engineSet->setItems(list);
-
-	//connect(engineSet, SIGNAL(triggered(bool)), SLOT(setupEngine()));
-
 	// AB: what the heck has this to do with redisplay? perhaps use reload instead?
 	//loadAction = KStandardAction::redisplay(this, SLOT(load()), actionCollection(), "move_load");
 	//loadAction->setEnabled(false);
@@ -212,8 +201,7 @@ KBg::KBg()
 	for (int i = 0; i < MaxEngine; i++)
 		engine[i] = 0;
 	currEngine = None;
-	engineSet->setCurrentItem(Offline);
-	setupEngine();
+	setupEngine(Offline);
 
 	/*
 	 * Set up configuration handling.
@@ -262,33 +250,21 @@ KBg::~KBg() {}
 // == engine handling ==========================================================
 
 /*
- * Set the engine according to the currently selected item in the
- * engineSet action. Additional engines have to be added to the switch
- * statement (and only there).
+ * Set the engine according to newEngine.
+ * Additional engines have to be added to the switchstatement (and only there).
  */
-void KBg::setupEngine()
+void KBg::setupEngine(int newEngine)
 {
-	/*
-	 * Get new engine type
-	 */
-	int type = engineSet->currentItem();
-
 	/*
 	 * Engine doesn't need to be changed?
 	 */
-	// was originally first 'if' but that doesn't work for reasons I don't understand
-	if (engine[type]) {
-	//	kDebug() << "engine doesn't need to be changed";
-	//	return;
-	}
-	if ( type == currEngine )
+	if (newEngine == currEngine)
 		return;
 
 	/*
 	 * Check with the engine if it can be terminated
 	 */
 	if (currEngine != None && engine[currEngine] && !engine[currEngine]->queryClose()) {
-		engineSet->setCurrentItem(currEngine);
 		return;
 	}
 
@@ -306,7 +282,8 @@ void KBg::setupEngine()
 		engine[currEngine] = 0;
 	}
 
-	switch (currEngine = type) {
+	currEngine = newEngine;
+	switch (currEngine) {
 	case Offline:
 		kDebug()<<"Setting engine type: Offline";
 		engine[currEngine] = new KBgEngineOffline(this, commandMenu);
@@ -454,8 +431,7 @@ void KBg::readConfig()
 	 * Restore last engine
 	 */
 	config.changeGroup("engine settings");
-	engineSet->setCurrentItem((Engines)config.readEntry("last engine", int(Offline)));
-	setupEngine();
+	setupEngine((Engines)config.readEntry("last engine",int(Offline)));
 }
 
 
@@ -468,9 +444,10 @@ void KBg::readConfig()
 void KBg::setupOk()
 {
 	// game type
+	int gameType;
 	for (int i = 0; i < 3; ++i) {
  		if ( rbEngine[i]->isChecked() )
-			engineSet->setCurrentItem(i);
+			gameType = i;
  	}
 
 	// global settings
@@ -481,7 +458,7 @@ void KBg::setupOk()
 	config.writeEntry("autosave on exit", cbs->isChecked());
 
 	config.changeGroup("engine");
-	config.writeEntry("last engine",      engineSet->currentItem());
+	config.writeEntry("last engine",      gameType);
 
 
 	// tell engine about commit timer
@@ -498,7 +475,7 @@ void KBg::setupOk()
 	for (int i = 0; i < MaxEngine; i++)
 		engine[i]->setupOk();
 	// will reset engine if it has changed
-	setupEngine();
+	setupEngine(gameType);
 
 	// save it all
 	saveConfig();
@@ -640,7 +617,7 @@ void KBg::setupDlg()
 	 * Enable messages
 	 */
 	gbm->setWhatsThis( i18n("Check the box to enable all the messages that you have previously "
-				  "disabled by choosing the \"Don't show this message again\" option."));
+				  "disabled by choosing the \"Do not show this message again\" option."));
 
 	QGridLayout *glm = new QGridLayout(gbm);
 	glm->setMargin(nb->spacingHint());
