@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbg.h 654728 2007-04-16 20:44:36Z hausmann $
+  $Id: kbg.h 713104 2007-09-16 11:53:07Z mlaurent $
 
 */
 
@@ -32,7 +32,6 @@ class QMenu;
 class QLabel;
 class QAction;
 class QRadioButton;
-class KSelectAction;
 class KLineEdit;
 class KPageDialog;
 class KDoubleNumInput;
@@ -81,7 +80,7 @@ public slots:
 	/**
 	 * Sets the backgammon engine to type
 	 */
-	void setupEngine();
+	void setupEngine(int newEngine);
 
 	void startKCM(const QString &);
 
@@ -203,7 +202,6 @@ private:
 	QMenu *dummyPopup;
 	enum HelpTpoics {FIBSHome, RuleHome, MaxHelpTopic};
 	QString helpTopic[MaxHelpTopic][2];
-	KSelectAction *engineSet;
 
 	/**
 	 * Notebook for the setup
