@@ -1650,7 +1650,7 @@ KBgBoardBar::KBgBoardBar(QWidget * parent, int numID)
 				   "on the bar and remain there until they can be put back "
 				   "on the board. Checkers can be moved by dragging them to "
 				   "their destination or by using the 'short move' feature.\n\n"
-				   "If the cube hasn't been doubled yet and if it can be used, "
+				   "If the cube has not been doubled yet and if it can be used, "
 				   "its face shows 64 and if the cube can be doubled, double "
 				   "clicking it will do so."));
 }
