@@ -107,7 +107,7 @@ class KBgBoard : public QWidget
 	/**
 	 * Constructor and destructor. Parameter as usual.
 	 */
-	KBgBoard(QWidget *parent = 0, QMenu *menu = 0);
+	explicit KBgBoard(QWidget *parent = 0, QMenu *menu = 0);
 	virtual ~KBgBoard();
 
 	/**
@@ -902,7 +902,7 @@ public:
 	/**
 	 * Constructor
 	 */
-	KBgBoardSetup(QWidget *parent = 0, QMenu *menu = 0);
+	explicit KBgBoardSetup(QWidget *parent = 0, QMenu *menu = 0);
 
 	/**
 	 * Lets the board put its setup pages into the notebook nb
