@@ -19,7 +19,8 @@ class ChatWidget;
 class Button;
 class QTcpSocket;
 class QStatusBar;
-class QLabel;
+class Entity;
+class Protocol;
 
 class SimpleMenu : public QObject
 {
@@ -30,7 +31,7 @@ Q_OBJECT
     Button* m_server_btn;
     Button* m_client_btn;
     
-    QTcpSocket* m_socket;
+    Protocol* m_protocol;
     QString m_nickname;
     
     enum State
@@ -41,23 +42,28 @@ Q_OBJECT
         DONE_CLIENT,
         DONE_GGZ_CLIENT
     } m_state;
-    void finalize(State);
+    
+    Entity* m_player1;
+    Entity* m_player2;
+    
+    void finalize(State, const QString& nick, QTcpSocket* socket = 0);
 public:
     SimpleMenu(QWidget* parent, WelcomeScreen* screen);
     
-    void setupController(Controller* controller,
-        SeaView* sea, ChatWidget* chat, 
-        QStatusBar* sbar, QLabel** player_label);
+    void setupController(Controller* controller, Entity* old_opponent,
+        SeaView* sea, ChatWidget* chat, bool ask = false);
     void runGGZ(int fd);
-private slots:
+    
+    Entity* player(int p) { return p == 0 ? m_player1 : m_player2; }
+    
+    static const char* iconLocal;
+    static const char* iconServer;
+    static const char* iconClient;
+public slots:
     void localGame();
     
     void createServer();
-    void processServerConnection();
-
     void createClient();
-    void clientError();
-    void clientOK();
 signals:
     void done();
 };
