@@ -1,6 +1,6 @@
 /*******************************************************************
  *
- * Copyright 2006 Dmitry Suzdalev <dimsuz@gmail.com>
+ * Copyright 2006-2007 Dmitry Suzdalev <dimsuz@gmail.com>
  *
  * This file is part of the KDE project "KLines"
  *
@@ -15,36 +15,28 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with KAtomic; see the file COPYING.  If not, write to
+ * along with KLines; see the file COPYING.  If not, write to
  * the Free Software Foundation, 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
  ********************************************************************/
-#include <QResizeEvent>
-#include <QGraphicsSceneMouseEvent>
-
-#include <kdebug.h>
-
 #include "scene.h"
 #include "ballitem.h"
+#include "previewitem.h"
 #include "animator.h"
 #include "renderer.h"
 
-KLinesView::KLinesView( KLinesScene* scene, QWidget* parent )
-    : QGraphicsView(scene, parent)
-{
-    //setMinimumSize( defaultFieldSize, defaultFieldSize );
-}
+#include <QGraphicsSceneMouseEvent>
+#include <QPainter>
 
-void KLinesView::resizeEvent( QResizeEvent* ev )
-{
-    static_cast<KLinesScene*>(scene())->resizeScene( ev->size().width(), ev->size().height() );
-}
-
-// =============== KLinesScene =======================
+#include <KGamePopupItem>
+#include <KLocale>
+#include <KDebug>
 
 KLinesScene::KLinesScene( QObject* parent )
-    : QGraphicsScene(parent), m_numFreeCells(FIELD_SIZE*FIELD_SIZE), m_score(0), m_bonusScore(0), m_cellSize(32)
+    : QGraphicsScene(parent),
+      m_playFieldOrigin(0, 0 ), m_numFreeCells(FIELD_SIZE*FIELD_SIZE),
+      m_score(0), m_bonusScore(0), m_cellSize(32), m_previewZoneVisible(true)
 {
     m_animator = new KLinesAnimator(this);
     connect( m_animator, SIGNAL(moveFinished()), SLOT(moveAnimFinished() ) );
@@ -55,27 +47,40 @@ KLinesScene::KLinesScene( QObject* parent )
     m_focusItem->setZValue(1.0);
     m_focusItem->setPen( Qt::DashLine );
 
+    m_previewItem = new PreviewItem(this);
+    m_previewItem->setPos( 0, 0 );
+
+    m_popupItem = new KGamePopupItem;
+    addItem(m_popupItem);
+
     startNewGame();
 }
 
 void KLinesScene::startNewGame()
 {
+    if(m_animator->isAnimating())
+        return;
+
     // reset all vars
     m_selPos = FieldPos();
     m_numFreeCells = FIELD_SIZE*FIELD_SIZE;
     m_score = 0;
     m_bonusScore = 0;
     m_placeBalls = true;
+    m_gameOver = false;
     m_itemsToDelete.clear();
     m_nextColors.clear();
     m_focusItem->setPos(0, 0);
     m_focusItem->hide();
 
-    // remove all ball items from the scene
+    m_popupItem->forceHide();
+
+    // remove all ball items from the scene leaving other items untouched
     QList<QGraphicsItem*> itemlist = items();
     foreach( QGraphicsItem* item, itemlist )
     {
-        if( item != m_focusItem )
+        BallItem* ball = qgraphicsitem_cast<BallItem*>(item);
+        if( ball )
         {
             removeItem(item);
             delete item;
@@ -94,7 +99,7 @@ void KLinesScene::startNewGame()
         m_nextColors.append(c);
     }
 
-    emit enableUndo(false);
+    emit stateChanged("not_undoable");
 
     nextThreeBalls();
 }
@@ -109,9 +114,22 @@ void KLinesScene::resizeScene(int width,int height)
     // store focus item field pos (calculated using old cellSize)
     FieldPos focusRectFieldPos = pixToField( m_focusItem->pos() );
 
-    m_cellSize = qMin(width, height)/FIELD_SIZE;
+    int minDim = qMin( width, height );
+    m_cellSize = minDim/FIELD_SIZE;
+
+    int boardSize = m_cellSize * FIELD_SIZE;
+    if (m_previewZoneVisible && boardSize + m_cellSize > width) // No space enough for balls preview
+    {
+        minDim = width;
+        m_cellSize = (minDim - m_cellSize)/FIELD_SIZE;
+        boardSize = m_cellSize * FIELD_SIZE;
+    }
+
+    m_playFieldOrigin = QPoint( (width - (m_previewZoneVisible ? m_cellSize : 0))/2 - boardSize/2, height/2 - boardSize/2 );
+
     setSceneRect( 0, 0, width, height );
 
+    // sets render sizes for cells
     KLinesRenderer::self()->setCellSize( m_cellSize );
 
     // re-render && recalc positions for all balls
@@ -129,11 +147,18 @@ void KLinesScene::resizeScene(int width,int height)
     m_focusItem->setRect( QRect(0,0, m_cellSize, m_cellSize) );
     m_focusItem->setPos( fieldToPix( focusRectFieldPos ) );
 
-    kDebug() << "resize:" << width << "," << height << "; cellSize: " << m_cellSize << endl;
+    int previewOriginY = height / 2 - (3 * m_cellSize) / 2;
+    m_previewItem->setPos( width-m_cellSize, previewOriginY );
+    m_previewItem->setPreviewColors( m_nextColors );
+
+    //kDebug() << "resize:" << width << "," << height << "; cellSize:" << m_cellSize;
 }
 
 void KLinesScene::endTurn()
 {
+    if( m_gameOver )
+        return;
+
     saveUndoInfo();
     nextThreeBalls();
 }
@@ -161,11 +186,22 @@ void KLinesScene::nextThreeBalls()
         m_nextColors[i] = c;
     }
 
-    emit nextColorsChanged();
+    m_previewItem->setPreviewColors( m_nextColors );
 
     m_animator->animateBorn( newItems );
 }
 
+void KLinesScene::setPreviewZoneVisible( bool visible )
+{
+    if (visible == m_previewZoneVisible)
+        return;
+
+    m_previewZoneVisible = visible;
+    m_previewItem->setVisible( visible );
+    resizeScene((int) width(), (int) height());
+    invalidate( sceneRect() );
+}
+
 BallItem* KLinesScene::randomlyPlaceBall(BallColor c)
 {
     m_numFreeCells--;
@@ -189,6 +225,11 @@ BallItem* KLinesScene::randomlyPlaceBall(BallColor c)
 
 void KLinesScene::mousePressEvent( QGraphicsSceneMouseEvent* ev )
 {
+    QGraphicsScene::mousePressEvent(ev);
+    if ( !QRectF( m_playFieldOrigin.x(), m_playFieldOrigin.y(),
+                  m_cellSize*FIELD_SIZE, m_cellSize*FIELD_SIZE ).contains( ev->scenePos() ) )
+        return;
+
     selectOrMove( pixToField(ev->scenePos()) );
 }
 
@@ -200,8 +241,16 @@ void KLinesScene::selectOrMove( const FieldPos& fpos )
     if( m_field[fpos.x][fpos.y] ) // ball was selected
     {
         if( m_selPos.isValid() )
+        {
             m_field[m_selPos.x][m_selPos.y]->stopAnimation();
 
+            if ( m_selPos == fpos )
+            {
+                m_selPos.x = m_selPos.y = -1; // invalidate position
+                return;
+            }
+        }
+
         m_field[fpos.x][fpos.y]->startSelectedAnimation();
         m_selPos = fpos;
     }
@@ -212,7 +261,12 @@ void KLinesScene::selectOrMove( const FieldPos& fpos )
             saveUndoInfo();
             // start move animation
             // slot moveAnimFinished() will be called when it finishes
-            m_animator->animateMove(m_selPos, fpos);
+            bool pathExists = m_animator->animateMove(m_selPos, fpos);
+            if(!pathExists)
+            {
+                m_popupItem->setMessageTimeout(2500);
+                m_popupItem->showMessage(i18n("Selected ball can not be moved to this cell"), KGamePopupItem::BottomLeft);
+            }
         }
     }
 }
@@ -242,12 +296,12 @@ void KLinesScene::removeAnimFinished()
 {
     if( m_itemsToDelete.isEmpty() && m_numFreeCells == 0 )
     {
-        emit enableUndo(false);
-        emit gameOver(m_score);
+        // game over
+        gameOverHandler();
         return;
     }
 
-    if(m_itemsToDelete.isEmpty() && m_placeBalls)
+    if( m_itemsToDelete.isEmpty() && m_placeBalls)
     {
         // slot bornAnimFinished() will be called
         // when born animation finishes
@@ -279,18 +333,16 @@ void KLinesScene::removeAnimFinished()
         if(numBallsErased)
             emit scoreChanged(m_score);
     }
-
 }
 
 void KLinesScene::bornAnimFinished()
 {
     // note that if m_numFreeCells == 0, we still need to
     // check for possible 5-in-a-row balls, i.e. call searchAndErase()
-    // So there's another gameOver()-check in removeAnimFinished()
+    // So there's another gameOver-check in removeAnimFinished()
     if( m_numFreeCells < 0 )
     {
-        kDebug() << "GAME OVER" << endl;
-        emit gameOver(m_score);
+        gameOverHandler();
         return;
     }
     // There's a little trick here:
@@ -313,7 +365,7 @@ void KLinesScene::bornAnimFinished()
 void KLinesScene::searchAndErase()
 {
     // FIXME dimsuz: put more comments about bounds in for loops
-    
+
     // horizontal chunks searching
     for(int x=0; x<FIELD_SIZE-4; ++x)
         for(int y=0;y<FIELD_SIZE; ++y)
@@ -374,7 +426,7 @@ void KLinesScene::searchAndErase()
             BallColor col = m_field[x][y]->color();
             int tmpx = x+1;
             int tmpy = y+1;
-            while(tmpx < FIELD_SIZE && tmpy < FIELD_SIZE && 
+            while(tmpx < FIELD_SIZE && tmpy < FIELD_SIZE &&
                     m_field[tmpx][tmpy] && m_field[tmpx][tmpy]->color() == col)
             {
                 tmpx++;
@@ -404,7 +456,7 @@ void KLinesScene::searchAndErase()
             BallColor col = m_field[x][y]->color();
             int tmpx = x+1;
             int tmpy = y-1;
-            while(tmpx < FIELD_SIZE && tmpy >=0 && 
+            while(tmpx < FIELD_SIZE && tmpy >=0 &&
                     m_field[tmpx][tmpy] && m_field[tmpx][tmpy]->color() == col)
             {
                 tmpx++;
@@ -437,12 +489,12 @@ void KLinesScene::moveFocusLeft()
         // no action for the first time
         return;
     }
+    FieldPos focusPos = pixToField( m_focusItem->pos() );
+    focusPos.x--;
+    if (focusPos.x < 0) // rotate on the torus
+        focusPos.x = FIELD_SIZE - 1;
 
-    QPointF pos = m_focusItem->pos();
-    pos.rx() -= m_cellSize;
-    if( pos.x() < 0 )
-        pos.setX( (FIELD_SIZE - 1)*m_cellSize );
-    m_focusItem->setPos( pos );
+    m_focusItem->setPos ( fieldToPix( focusPos ) );
 }
 
 void KLinesScene::moveFocusRight()
@@ -453,12 +505,12 @@ void KLinesScene::moveFocusRight()
         // no action for the first time
         return;
     }
+    FieldPos focusPos = pixToField( m_focusItem->pos() );
+    focusPos.x++;
+    if (focusPos.x >= FIELD_SIZE) // rotate on the torus
+        focusPos.x = 0;
 
-    QPointF pos = m_focusItem->pos();
-    pos.rx() += m_cellSize;
-    if( pos.x() > (FIELD_SIZE-1)*m_cellSize )
-        pos.setX( 0 );
-    m_focusItem->setPos( pos );
+    m_focusItem->setPos ( fieldToPix( focusPos ) );
 }
 
 void KLinesScene::moveFocusUp()
@@ -469,12 +521,12 @@ void KLinesScene::moveFocusUp()
         // no action for the first time
         return;
     }
+    FieldPos focusPos = pixToField( m_focusItem->pos() );
+    focusPos.y--;
+    if (focusPos.y < 0) // rotate on the torus
+        focusPos.y = FIELD_SIZE - 1;
 
-    QPointF pos = m_focusItem->pos();
-    pos.ry() -= m_cellSize;
-    if( pos.y() < 0 )
-        pos.setY( (FIELD_SIZE - 1)*m_cellSize );
-    m_focusItem->setPos( pos );
+    m_focusItem->setPos ( fieldToPix( focusPos ) );
 }
 
 void KLinesScene::moveFocusDown()
@@ -486,11 +538,12 @@ void KLinesScene::moveFocusDown()
         return;
     }
 
-    QPointF pos = m_focusItem->pos();
-    pos.ry() += m_cellSize;
-    if( pos.y() > (FIELD_SIZE-1)*m_cellSize )
-        pos.setY( 0 );
-    m_focusItem->setPos( pos );
+    FieldPos focusPos = pixToField( m_focusItem->pos() );
+    focusPos.y++;
+    if (focusPos.y >= FIELD_SIZE) // rotate on the torus
+        focusPos.y = 0;
+
+    m_focusItem->setPos ( fieldToPix( focusPos ) );
 }
 
 void KLinesScene::cellSelected()
@@ -513,7 +566,7 @@ void KLinesScene::saveUndoInfo()
     m_undoInfo.score = m_score;
     m_undoInfo.nextColors = m_nextColors;
 
-    emit enableUndo(true);
+    emit stateChanged("undoable");
 }
 
 // Brings m_field and some other vars to the state it was before last turn
@@ -559,17 +612,35 @@ void KLinesScene::undo()
 
     m_selPos = FieldPos();
 
+    m_previewItem->setPreviewColors( m_nextColors );
+
     emit scoreChanged(m_score);
-    emit nextColorsChanged();
-    emit enableUndo(false);
+
+    emit stateChanged("not_undoable");
 }
 
 void KLinesScene::drawBackground(QPainter *p, const QRectF&)
 {
-    // FIXME dimsuz: temp
-    for(int x=0; x<m_cellSize*FIELD_SIZE;x+=m_cellSize)
-        for(int y=0; y<m_cellSize*FIELD_SIZE;y+=m_cellSize)
-            p->drawPixmap( x, y, KLinesRenderer::self()->backgroundTilePixmap() );
+    QPixmap tile = KLinesRenderer::self()->backgroundTilePixmap();
+    p->drawPixmap( 0,0, KLinesRenderer::self()->backgroundPixmap(sceneRect().size().toSize()) );
+    for(int x=m_playFieldOrigin.x(); x<m_playFieldOrigin.x()+m_cellSize*FIELD_SIZE;x+=m_cellSize)
+        for(int y=m_playFieldOrigin.y(); y<m_playFieldOrigin.y()+m_cellSize*FIELD_SIZE;y+=m_cellSize)
+            p->drawPixmap( x, y, tile );
+}
+
+void KLinesScene::gameOverHandler()
+{
+    if( m_gameOver )
+        return; // don't emit twice
+    m_gameOver = true;
+    kDebug() << "GAME OVER";
+    emit stateChanged("not_undoable");
+    //emit enableUndo(false);
+    emit gameOver(m_score);
+
+    // disable auto-hide
+    m_popupItem->setMessageTimeout(0);
+    m_popupItem->showMessage("<h1>Game over</h1>", KGamePopupItem::Center);
 }
 
 #include "scene.moc"
