@@ -59,28 +59,14 @@ BoardWidget::BoardWidget( QWidget* parent )
     m_angle = NE;
 
     // Load layout first
-    QString tFile;
-
-    getFileOrDefault(Prefs::layout(), "layout", tFile);
-    if( ! loadBoardLayout(tFile) )
-    {
-	KMessageBox::information(this,
-		   i18n("An error occurred when loading the board layout %1\n"
-                "KMahjongg will continue with the default layout.", tFile));
-    }
+    loadBoardLayout(Prefs::layout());
 
     //Initialize our Game structure
-    Game = new GameData(&theBoardLayout);
+    Game = new GameData(theBoardLayout.board());
 
     MouseClickPos1.e = Game->m_depth;     // mark tile position as invalid
     MouseClickPos2.e = Game->m_depth;
 
-    //Now apply our visual settings
-
-
-    //setDisplayedWidth();
-    loadSettings();
-    
     //Animation timers
     animateForwardTimer = new QTimer(this);
     animateForwardTimer->setSingleShot(true);
@@ -93,28 +79,37 @@ BoardWidget::BoardWidget( QWidget* parent )
     animateBackwardsTimer->setInterval(100);
     connect(animateBackwardsTimer, SIGNAL(timeout()), SLOT(animatingMoveListBackwards()));
     animateBackwardsTimer->stop();
+    
+    loadSettings();
 }
 
 BoardWidget::~BoardWidget(){
-  saveSettings();
   if (Game) delete Game;
 }
 
 void BoardWidget::loadSettings(){
-    QString tFile;
     // Load tileset. First try to load the last use tileset
 
     if (!loadTileset(Prefs::tileSet())){
-        kDebug() << "An error occurred when loading the tileset" << tFile <<"KMahjongg will continue with the default tileset.";
+      kDebug() << "An error occurred when loading the tileset" << Prefs::tileSet() <<"KMahjongg will continue with the default tileset.";
     }
 
     // Load background
     if( ! loadBackground(Prefs::background(), false ) )
     {
-	kDebug() << "An error occurred when loading the background" << tFile <<"KMahjongg will continue with the default background.";
+      kDebug() << "An error occurred when loading the background" << Prefs::background() <<"KMahjongg will continue with the default background.";
+    }
+    setShowMatch( Prefs::showMatchingTiles() );
+    
+    if (QString::compare(Prefs::layout(), theBoardLayout.path(), Qt::CaseSensitive)!=0) {
+      //TODO: WARN USER HERE ABOUT DESTRUCTIVE OPERATION!!!
+      loadBoardLayout(Prefs::layout());
+      calculateNewGame();
     }
     setDisplayedWidth();
     drawBoard(true);
+    //Store our updated settings, some values might have been changed to defaults
+    saveSettings();
 }
 
 void BoardWidget::resizeEvent ( QResizeEvent * event )
@@ -127,9 +122,8 @@ void BoardWidget::resizeEvent ( QResizeEvent * event )
 
 void BoardWidget::resizeTileset ( const QSize & wsize )
 {
-    //qDebug() << "resized:" << event->oldSize() << event->size();
     QSize newtiles = theTiles.preferredTileSize(wsize, requiredHorizontalCells(), requiredVerticalCells());
-    //qDebug() << "new tilesize:" << newtiles;
+
     theTiles.reloadTileset(newtiles);
     stopMatchAnimation();
 }
@@ -137,34 +131,10 @@ void BoardWidget::resizeTileset ( const QSize & wsize )
 
 
 void BoardWidget::saveSettings(){
-  // Preview can't handle this.  TODO
-  //KSharedConfig::Ptr config = KGlobal::config();
-  //config->setGroup("General");
-
-  //config->writePathEntry("Tileset_file", tileFile);
-  //config->writePathEntry("Background_file", backgroundFile);
-  //config->writePathEntry("Layout_file", layout);
-}
-
-void BoardWidget::getFileOrDefault(const QString &filename, const QString &type, QString &res)
-{
-	QString picsPos = "pics/";
-	picsPos += "default.";
-	picsPos += type;
-
-	if (QFile::exists(filename)) {
-		res = filename;
-	}
-    else {
-        res = KStandardDirs::locate("appdata", picsPos);
-	}
-
-    if (res.isEmpty()) {
-		KMessageBox::error(this, i18n("KMahjongg could not locate the file: %1\n"
-                                      "or the default file of type: %2\n"
-                                      "KMahjongg will now terminate", filename, type) );
-		qApp->quit();
-	}
+  Prefs::setTileSet(theTiles.path());
+  Prefs::setLayout(theBoardLayout.path());
+  Prefs::setBackground(theBackground.path());
+  Prefs::self()->writeConfig();
 }
 
 void BoardWidget::setDisplayedWidth() {
@@ -404,196 +374,9 @@ void BoardWidget::updateSpriteMap() {
    }
 }
 
-// for a given cell x y calc how that cell is shadowed
-// returnd left = width of left hand side shadow
-// t = height of top shadow
-// c = width and height of corner shadow
-
-/*
-
-// ---------------------------------------------------------
-void BoardWidget::paintEvent( QPaintEvent* pa )
-{
-    QPixmap  *back;
-
-    int xx = pa->rect().left();
-    int xheight = pa->rect().height();
-    int xwidth  = pa->rect().width();
-
-    back = theBackground.getBackground();
-
-    QPainter p;
-    if (gamePaused) {
-        // If the game is paused, then blank out the board.
-        // We tolerate no cheats around here folks..
-        p.begin(this);
-        p.drawPixmap( xx, pa->rect().top(),
-                *back, xx, pa->rect().top(), xwidth, xheight );
-        p.end();
-	return;
-    }
-
-    // if the repaint is because of a window redraw after a move
-    // or a menu roll up, then just blit in the last rendered image
-    if (!updateBackBuffer) {
-        p.begin(this);
-    	p.drawPixmap( xx,pa->rect().top(),
-		backBuffer, xx, pa->rect().top(), xwidth, xheight );
-        p.end();
-	return;
-    }
-
-    // update the complete drawArea
-
-    backBuffer = QPixmap(back->width(), back->height());
-
-    // erase out with the background
-    p.begin(&backBuffer);
-    p.drawPixmap( xx, pa->rect().top(),
-                *back, xx,pa->rect().top(), back->width(), back->height() );
-
-    // initial offset on the screen of tile 0,0
-    int xOffset = theTiles.width()/2;
-    int yOffset = theTiles.height()/2;
-    //short tile = 0;
-
-
-    // we iterate over the depth stacking order. Each successive level is
-    // drawn one indent up and to the right. The indent is the width
-    // of the 3d relief on the tile left (tile shadow width)
-    for (int z=0; z<BoardLayout::depth; z++) {
-        // we draw down the board so the tile below over rights our border
-        for (int y = 0; y < BoardLayout::height; y++) {
-            // drawing right to left to prevent border overwrite
-            for (int x=BoardLayout::width-1; x>=0; x--) {
-                int sx = x*(theTiles.qWidth()  )+xOffset;
-                int sy = y*(theTiles.qHeight()  )+yOffset;
-
-		// skip if no tile to display
-		if (!Game->tilePresent(z,y,x))
-			continue;
-
-                QPixmap *t;
-		if (Game->hilighted[z][y][x]) {
-		   t= theTiles.selectedPixmaps(
-				Game->Board[z][y][x]-TILE_OFFSET);
-		} else {
-		   t= theTiles.unselectedPixmaps(
-				Game->Board[z][y][x]-TILE_OFFSET);
-                }
-
-                // Only one compilcation. Since we render top to bottom , left
-                // to right situations arise where...:
-                // there exists a tile one q height above and to the left
-                // in this situation we would draw our top left border over it
-                // we simply split the tile draw so the top half is drawn
-                // minus border
-
-                //TODO convert to QGV and let it layer everything properly
-                    p.drawPixmap(  sx, sy, *t, 0,0, t->width(), t->height() );
-
-
-            }
-        }
-        xOffset +=theTiles.levelOffset();
-        yOffset -=theTiles.levelOffset();
-    }
-
-
-    // Now we add the list of canceled tiles
-//TODO major overhaul of this functionality
-if (Prefs::showRemoved()) {
-
-    // we start blitting as usuall right to left, top to bottom, first
-    // we calculate the start pos of the first tile, allowing space for
-    // the upwards at rightwards creep when stacking in 3d
-    unsigned short xPos = backBuffer.width()-(3*theTiles.levelOffset())-theTiles.width();
-    unsigned short yPos = (3*theTiles.levelOffset());
-
-    for (int pos=0; pos < 9; pos++) {
-	int last = 0;
-	int tile=0;
-	// dragon?
-	if (pos >= 0 && pos < 3) {
-		last = removedDragon[pos];
-		tile = TILE_DRAGON+pos;
-	} else {
-	    //Wind?
-	    if (pos >= 3 && pos < 7) {
-	        last = removedWind[pos-3];
-		tile = TILE_WIND+pos-3;
-	    } else {
-		if (pos == 7) {
-		    for (int t=0; t<4;t++) {
-		        if (removedFlower[t]) {
-			    last++;
-			    tile=TILE_FLOWER+t;
-			}
-		    }
-		} else {
-		    for (int t=0; t<4;t++) {
-		        if (removedSeason[t]) {
-			    last++;
-			    tile=TILE_SEASON+t;
-			}
-		    }
-		}
-	    }
-	}
-
-	    stackTiles(&p, tile, last, xPos, yPos);
-	    stackTiles(&p, TILE_ROD+pos, removedRod[pos],
-		xPos - (1*(theTiles.width() - theTiles.levelOffset())) , yPos);
-	    stackTiles(&p, TILE_BAMBOO+pos, removedBamboo[pos],
-		xPos - (2*(theTiles.width() - theTiles.levelOffset())) , yPos);
-	    stackTiles(&p, TILE_CHARACTER+pos, removedCharacter[pos],
-		xPos - (3*(theTiles.width() - theTiles.levelOffset())) , yPos);
-
-
-
-	yPos += theTiles.height()-theTiles.levelOffset();
-    }
-} //removed
-
-    updateBackBuffer=false;
-    p.end(); //backbuffer
-    p.begin(this);
-    p.drawPixmap(xx,pa->rect().top(), backBuffer, xx, pa->rect().top(), xwidth, xheight);
-    p.end();
-}*/
-
-void BoardWidget::stackTiles(QPainter* p, unsigned char t, unsigned short h, unsigned short x,unsigned  short y)
-{
-    int ss = theTiles.levelOffsetX();
-    QPen line;
-    p->setBackgroundMode(Qt::OpaqueMode);
-    p->setBackground(Qt::black);
-
-    line.setWidth(1);
-    line.setColor(Qt::white);
-    p->save();
-    p->setPen(line);
-    int x2 = x+theTiles.width()-ss-1;
-    int y2 = y+theTiles.height()-1;
-    p->drawLine(x, y+ss, x2, y+ss);
-    p->drawLine(x, y+ss, x, y2);
-    p->drawLine(x2, y+ss, x2, y2);
-    p->drawLine(x+1, y2, x2, y2);
-
-   // p.fillRect(x+1, y+ss+1, theTiles.width()-ss-2, theTiles.height()-ss-2, QBrush(lightGray));
-
-    for (unsigned short pos=0; pos < h; pos++) {
-       QPixmap pix = theTiles.tileface(t-TILE_OFFSET);
-       p->drawPixmap( x+(pos*ss), y-(pos*ss),
-                    pix );
-    }
-    p->restore();
-}
-
-
 void BoardWidget::pause() {
 	gamePaused = !gamePaused;
-	drawBoard(true);
+	drawBoard(!gamePaused);
 }
 
 void BoardWidget::gameLoaded()
@@ -607,7 +390,8 @@ void BoardWidget::gameLoaded()
 		Game->setRemovedTilePair(Game->MoveListData(i), Game->MoveListData(i+1));
 		i +=2;
 	}
-	drawBoard();
+        populateSpriteMap();
+	drawBoard(true);
 }
 
 // ---------------------------------------------------------
@@ -783,14 +567,14 @@ void BoardWidget::matchAnimationTimeout()
     {
         for(short Pos = 0; Pos < matchCount; Pos++)
         {
-            hilightTile(Game->PosTable[Pos], true);
+          hilightTile(Game->getFromPosTable(Pos), true);
         }
     }
     else
     {
         for(short Pos = 0; Pos < matchCount; Pos++)
         {
-            hilightTile(Game->PosTable[Pos], false);
+          hilightTile(Game->getFromPosTable(Pos), false);
         }
     }
     if( TimerState == Match )
@@ -801,7 +585,7 @@ void BoardWidget::stopMatchAnimation()
 {
     for(short Pos = 0; Pos < matchCount; Pos++)
     {
-        hilightTile(Game->PosTable[Pos], false);
+      hilightTile(Game->getFromPosTable(Pos), false);
     }
     TimerState = Stop;
     matchCount = 0;
@@ -821,28 +605,6 @@ void BoardWidget::animateMoveList()
 {
     setStatusText( i18n("Congratulations. You have won!") );
     animatingMoveListForward();
-
-    /*if (Prefs::playAnimation())
-    {
-        while( Game->TileNum < Game->MaxTileNum )
-        {
-            // put back all tiles
-            putTileInBoard(Game->MoveListData(Game->TileNum));
-            Game->TileNum++;
-            putTileInBoard(Game->MoveListData(Game->TileNum), false);
-            Game->TileNum++;
-            drawTileNumber();
-        }
-        while( Game->TileNum > 0 )
-        {
-            // remove all tiles
-            removeTile(Game->MoveListData(Game->TileNum-1), false);
-            removeTile(Game->MoveListData(Game->TileNum-1));
-            drawTileNumber();
-        }
-    }
-
-    calculateNewGame();*/
 }
 
 void BoardWidget::animatingMoveListForward()
@@ -907,7 +669,6 @@ void BoardWidget::calculateNewGame( int gNumber)
 
     // Translate Game->Map to an array of POSITION data.  We only need to
     // do this once for each new game.
-    //memset(Game->tilePositions, 0, sizeof(Game->tilePositions));
     Game->generateTilePositions();
 
     // Now use the tile position data to generate tile dependency data.
@@ -919,14 +680,14 @@ void BoardWidget::calculateNewGame( int gNumber)
     {
         if( Game->generateStartPosition2() )
         {
-            drawBoard();
+            drawBoard(true);
             setStatusText( i18n("Ready. Now it is your turn.") );
 			cheatsUsed=0;
 	    return;
         }
     }
 
-    drawBoard();
+    drawBoard(true);
     setStatusText( i18n("Error generating new game!") );
 }
 
@@ -948,14 +709,10 @@ void BoardWidget::hilightTile( POSITION& Pos, bool on, bool doRepaint )
 	if (on) {
 		Game->setHighlightData(Pos.e,Pos.y,Pos.x,1);
 		if (atile)
-		//atile->setPixmap(*(theTiles.selectedPixmaps(
-				//Game->BoardData(Pos.e,Pos.y,Pos.x)-TILE_OFFSET)));
 		atile->setSelected(true);
 	} else {
 		Game->setHighlightData(Pos.e,Pos.y,Pos.x,0);
 		if (atile)
-		//atile->setPixmap(*(theTiles.unselectedPixmaps(
-				//Game->BoardData(Pos.e,Pos.y,Pos.x)-TILE_OFFSET)));
 		atile->setSelected(false);
 	}
 }
@@ -963,10 +720,25 @@ void BoardWidget::hilightTile( POSITION& Pos, bool on, bool doRepaint )
 
 
 // ---------------------------------------------------------
-void BoardWidget::drawBoard(bool )
+void BoardWidget::drawBoard(bool showTiles)
 {
-   populateSpriteMap();
-   drawTileNumber();
+   if (showTiles) {
+    populateSpriteMap();
+    drawTileNumber();
+   } else {
+     //Delete previous sprites
+     while (!items()->isEmpty())
+       delete items()->first();
+
+    //Clear our spritemap as well
+     spriteMap.clear();
+
+    //Recreate our background
+     QPalette palette;
+     palette.setBrush( backgroundRole(), theBackground.getBackground() );
+     setPalette( palette );
+     setAutoFillBackground (true);
+   }
 }
 
 // ---------------------------------------------------------
@@ -987,10 +759,7 @@ void BoardWidget::putTileInBoard( POSITION& Pos, bool doRepaint )
     us= theTiles.unselectedTile(m_angle);
     f= theTiles.tileface(Game->BoardData(E,Y,X)-TILE_OFFSET);
     TileSprite * thissprite = new TileSprite(this, us, s, f, m_angle, false);
-    //thissprite->moveTo(sx, sy);
-    //thissprite->setOpacity(0);
     thissprite->show();
-    //thissprite->fadeIn();
     spriteMap.insert(TileCoord(X,Y,E), thissprite);
 
     updateSpriteMap();
@@ -1010,8 +779,6 @@ void BoardWidget::removeTile( POSITION& Pos , bool doRepaint)
 
     TileSprite * thissprite =spriteMap.value(TileCoord(X,Y,E));
     if (thissprite) delete thissprite;
-    //fade out, TileSprite will delete itself
-    //if (thissprite) thissprite->fadeOut();
 
     spriteMap.remove(TileCoord(X,Y,E));
     // remove tile from game board
@@ -1173,7 +940,7 @@ void BoardWidget::transformPointToPosition(
 bool BoardWidget::loadBoard( )
 {
     if (Game) delete Game;
-    Game = new GameData(&theBoardLayout);
+    Game = new GameData(theBoardLayout.board());
     return(true);
 }
 
@@ -1190,18 +957,16 @@ bool BoardWidget::loadBackground(
     )
 {
   if (theBackground.load( pszFileName, requiredWidth(), requiredHeight())) {
-    Prefs::setBackground(pszFileName);
-    Prefs::self()->writeConfig();
-    return true;
-  } else {
-    if (theBackground.loadDefault()) {
-      Prefs::setBackground(theBackground.path());
-      Prefs::self()->writeConfig();
-      return false;
-    } else {
-      return false;
+    if (theBackground.loadGraphics()) {
+      return true;
     }
-  }
+  } 
+  //Try default
+    if (theBackground.loadDefault()) {
+      if (theBackground.loadGraphics()) {
+      }
+    } 
+    return false;
 }
 
 // ---------------------------------------------------------
@@ -1224,30 +989,30 @@ void BoardWidget::cancelUserSelectedTiles()
 bool BoardWidget::loadTileset(const QString &path) {
 
   if (theTiles.loadTileset(path)) {
-    Prefs::setTileSet(path);
-    Prefs::self()->writeConfig();
+    if (theTiles.loadGraphics()) {
+      resizeTileset(size());
+      return true;
+    }
+  } 
+  //Tileset or graphics could not be loaded, try default
+  if (theTiles.loadDefault()) {
+    if (theTiles.loadGraphics()) {
     resizeTileset(size());
+    }
+  } 
+  return false;
+}
+
+bool BoardWidget::loadBoardLayout(const QString &file) {
+  if (theBoardLayout.load(file)) {
     return true;
   } else {
-    if (theTiles.loadDefault()) {
-      Prefs::setTileSet(theTiles.path());
-      Prefs::self()->writeConfig();
-      resizeTileset(size());
+    if (theBoardLayout.loadDefault()) {
       return false;
     } else {
       return false;
     }
   }
-
-}
-
-bool BoardWidget::loadBoardLayout(const QString &file) {
-  if (theBoardLayout.loadBoardLayout(file)) {
-    Prefs::setLayout(file);
-    Prefs::self()->writeConfig();
-    return true;
-  }
-  return false;
 }
 
 int BoardWidget::requiredHorizontalCells()
@@ -1337,55 +1102,19 @@ void BoardWidget::angleSwitchCW() {
 // shuffle the remaining tiles around, useful if a deadlock ocurrs
 // this is a big cheat so we penalise the user.
 void BoardWidget::shuffle() {
-	int count = 0;
-	// copy positions and faces of the remaining tiles into
-	// the pos table
-	for (int e=0; e<Game->m_depth; e++) {
-	    for (int y=0; y<Game->m_height; y++) {
-		for (int x=0; x<Game->m_width; x++) {
-		    if (Game->BoardData(e,y,x) && Game->MaskData(e,y,x) == '1') {
-			Game->PosTable[count].e = e;
-			Game->PosTable[count].y = y;
-			Game->PosTable[count].x = x;
-			Game->PosTable[count].f = Game->BoardData(e,y,x);
-			count++;
-		    }
-		}
-	    }
+  Game->shuffle();
+  // force a full redraw
+  populateSpriteMap();
 
-	}
-
-
-	// now lets randomise the faces, selecting 400 pairs at random and
-	// swapping the faces.
-	for (int ran=0; ran < 400; ran++) {
-		int pos1 = Game->random.getLong(count);
-		int pos2 = Game->random.getLong(count);
-		if (pos1 == pos2)
-			continue;
-		BYTE f = Game->PosTable[pos1].f;
-		Game->PosTable[pos1].f = Game->PosTable[pos2].f;
-		Game->PosTable[pos2].f = f;
-	}
-
-	// put the rearranged tiles back.
-	for (int p=0; p<count; p++)
-		Game->putTile(Game->PosTable[p]);
-
-
-	// force a full redraw
-	populateSpriteMap();
-
-	// I consider this s very bad cheat so, I punish the user
-	// 300 points per use
-	cheatsUsed += 15;
-	drawTileNumber();
+  // I consider this s very bad cheat so, I punish the user
+  // 300 points per use
+  cheatsUsed += 15;
+  drawTileNumber();
 }
 
 QString  BoardWidget::getLayoutName() {
-    //TODO: switch layout format to .desktop files, get localized name of board
-    QFileInfo layoutinfo(theBoardLayout.getFilename());
-    return layoutinfo.baseName();
+    QString key("Name");
+    return theBoardLayout.authorProperty(key);
 }
 
 
