@@ -37,6 +37,7 @@
 
 #include <QPixmapCache>
 #include <QLabel>
+#include <QDesktopWidget>
 
 #include <kio/netaccess.h>
 #include <klocale.h>
@@ -44,12 +45,14 @@
 #include <kactioncollection.h>
 
 #include "prefs.h"
+#include "kmahjongglayoutselector.h"
 #include "ui_settings.h"
-#include "Editor.h"
+//#include "Editor.h"
 
 #include <kmahjonggconfigdialog.h>
 
-static const char *gameMagic = "kmahjongg-game-v1.0";
+static const char *gameMagic = "kmahjongg-gamedata";
+static int gameDataVersion = 1;
 
 //----------------------------------------------------------
 // Defines
@@ -93,8 +96,6 @@ KMahjongg::KMahjongg( QWidget* parent)
     bw = new BoardWidget( this );
     setCentralWidget( bw );
 
-    previewLoad = new Preview(this);
-
     setupStatusBar();
     setupKAction();
 
@@ -127,22 +128,6 @@ KMahjongg::KMahjongg( QWidget* parent)
     connect(bw, SIGNAL(gameCalculated()),
       this, SLOT(timerReset()));
 
-    // Make connections for the preview load dialog
-    connect( previewLoad, SIGNAL( boardRedraw(bool) ),
-              bw,   SLOT( drawBoard(bool) ) );
-
-    connect( previewLoad, SIGNAL( layoutChange() ),
-              this,   SLOT( newGame() ) );
-
-
-    connect( previewLoad, SIGNAL( loadBackground(const QString&, bool) ),
-              bw,   SLOT(loadBackground(const QString&, bool) ) );
-
-    connect( previewLoad, SIGNAL( loadTileset(const QString &) ),
-               bw,  SLOT(loadTileset(const QString&) ) );
-    connect( previewLoad, SIGNAL( loadBoard(const QString&) ),
-                 SLOT(loadBoardLayout(const QString&) ) );
-
     startNewGame(  );
 
 }
@@ -150,7 +135,6 @@ KMahjongg::KMahjongg( QWidget* parent)
 // ---------------------------------------------------------
 KMahjongg::~KMahjongg()
 {
-    delete previewLoad;
     delete bw;
 }
 
@@ -170,28 +154,6 @@ void KMahjongg::setupKAction()
     newNumGame->setText(i18n("New Numbered Game..."));
     connect(newNumGame, SIGNAL(triggered(bool)), SLOT(startNewNumeric()));
 
-    /*TODO reimplement with game type and preferences
-    QAction* openTheme = actionCollection()->addAction"game_open_theme");
-    openTheme->setTexti18n("Open Th&eme...");
-    connect(openTheme, SIGNAL(triggered(bool)), SLOT(openTheme()));
-
-    QAction* openTileset = actionCollection()->addAction("game_open_tileset");
-    openTileset->setText(i18n("Open &Tileset..."));
-    connect(openTileset, SIGNAL(triggered(bool)), SLOT(openTileset()));*/
-
-   /* QAction* openBkgnd = actionCollection()->addAction"game_open_background");
-    openBkgnd->setTexti18n("Open &Background...");
-    connect(openBkgnd, SIGNAL(triggered(bool)), SLOT(openBackground()));*/
-
-    QAction* openLayout = actionCollection()->addAction("game_open_layout");
-    openLayout->setText(i18n("Open La&yout..."));
-    connect(openLayout, SIGNAL(triggered(bool)), SLOT(openLayout()));
-
-    /*TODO reimplement with game type and preferences
-    QAction* saveTheme = actionCollection()->addAction"game_save_theme");
-    saveTheme->setTexti18n("Sa&ve Theme...");
-    connect(saveTheme, SIGNAL(triggered(bool)), SLOT(saveTheme()));*/
-
     // originally "file" ends here
     action = KStandardGameAction::hint(bw, SLOT(helpMove()), this);
     actionCollection()->addAction(action->objectName(), action);
@@ -210,39 +172,23 @@ void KMahjongg::setupKAction()
     connect(angleccw, SIGNAL(triggered(bool)), bw, SLOT(angleSwitchCCW()));
     connect(anglecw, SIGNAL(triggered(bool)), bw, SLOT(angleSwitchCW()));
     demoAction = KStandardGameAction::demo(this, SLOT(demoMode()), actionCollection());
-    showMatchingTilesAction = new KToggleAction(i18n("Show &Matching Tiles"), this);
-    actionCollection()->addAction("options_show_matching_tiles", showMatchingTilesAction);
-    connect(showMatchingTilesAction, SIGNAL(triggered(bool)), SLOT(showMatchingTiles()));
-    showMatchingTilesAction->setCheckedState(KGuiItem(i18n("Hide &Matching Tiles")));
-    showMatchingTilesAction->setChecked(Prefs::showMatchingTiles());
-    bw->setShowMatch( Prefs::showMatchingTiles() );
     
     KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
     pauseAction = KStandardGameAction::pause(this, SLOT(pause()), actionCollection());
 
-    //TODO maybe add standard resizing actions for the view?
-    //we are currently using a resizable window for testing
-    //KStandardAction::actualSize(this, SLOT(makeFit()), actionCollection());
-    //KStandardAction::zoomIn(this, SLOT(makeLarger()), actionCollection());
-    //KStandardAction::zoomOut(this, SLOT(makeSmaller()), actionCollection());
-
-    // TODO: store the background ; open on startup
-    // TODO: same about layout
-    // TODO: same about theme
-
     // move
     undoAction = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
     redoAction = KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
 
     // edit
-    QAction* boardEdit = actionCollection()->addAction("edit_board_editor");
-    boardEdit->setText(i18n("&Board Editor"));
-    connect(boardEdit, SIGNAL(triggered(bool)), SLOT(slotBoardEditor()));
+    //QAction* boardEdit = actionCollection()->addAction("edit_board_editor");
+    //boardEdit->setText(i18n("&Board Editor"));
+    //connect(boardEdit, SIGNAL(triggered(bool)), SLOT(slotBoardEditor()));
 
     // settings
     KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 
-    setupGUI();
+    setupGUI(qApp->desktop()->availableGeometry().size()*0.7);
 }
 
 // ---------------------------------------------------------
@@ -324,6 +270,7 @@ void KMahjongg::showSettings(){
 
   //The Settings class is ours
   dialog->addPage(new Settings(0), i18n("General"), "package_settings");
+  dialog->addPage(new KMahjonggLayoutSelector(0, Prefs::self()), i18n("Board layout"), "board_layout");
   dialog->addTilesetPage();
   dialog->addBackgroundPage();
 
@@ -353,14 +300,6 @@ void KMahjongg::pause()
     bw->pause();
 }
 
-void KMahjongg::showMatchingTiles()
-{
-    Prefs::setShowMatchingTiles(!Prefs::showMatchingTiles());
-    bw->setShowMatch( Prefs::showMatchingTiles() );
-    showMatchingTilesAction->setChecked(Prefs::showMatchingTiles());
-    Prefs::self()->writeConfig();
-}
-
 void KMahjongg::showHighscores()
 {
     //theHighScores->exec(bw->getLayoutName());
@@ -369,44 +308,12 @@ void KMahjongg::showHighscores()
     ksdialog.exec();
 }
 
-/*TODO reimplement with game type and preferences
-void KMahjongg::openTheme()
-{
-    previewLoad->initialise(Preview::theme);
-    previewLoad->exec();
-}
-
-void KMahjongg::saveTheme()
-{
-    previewLoad->initialise(Preview::theme);
-    previewLoad->saveTheme();
-}*/
-
-void KMahjongg::openLayout()
-{
-    previewLoad->initialise(Preview::board);
-    previewLoad->exec();
-}
-
-/*TODO reimplement with game type and preferences
-void KMahjongg::openBackground()
-{
-    previewLoad->initialise(Preview::background);
-    previewLoad->exec();
-}
-
-void KMahjongg::openTileset()
-{
-    previewLoad->initialise(Preview::tileset);
-    previewLoad->exec();
-}*/
-
-void KMahjongg::slotBoardEditor()
+/*void KMahjongg::slotBoardEditor()
 {
     Editor *boardEditor = new Editor(this);
     boardEditor->exec();
     delete boardEditor;
-}
+}*/
 
 //----------------------------------------------------------
 // signalled from the prieview dialog to generate a new game
@@ -522,9 +429,6 @@ void KMahjongg::showTileNumber( int iMaximum, int iCurrent, int iLeft )
     // update undo menu item, if demomode is inactive
     if( ! bDemoModeActive && !is_paused)
     {
-
-//        pMenuBar->setItemEnabled( ID_EDIT_UNDO, bw->Game.allow_undo);
-//        toolBar->setItemEnabled( ID_EDIT_UNDO, bw->Game.allow_undo);
         undoAction->setEnabled(bw->Game->allow_undo);
     }
 }
@@ -548,61 +452,10 @@ void KMahjongg::demoModeChanged( bool bActive)
 	    redoAction->setEnabled(bw->Game->allow_redo);
     }
 }
-
+/*
 void KMahjongg::loadBoardLayout(const QString &file) {
 	bw->loadBoardLayout(file);
-}
-
-
-
-void KMahjongg::loadGame() {
-//TODO adapt to new GameData class
-/*
-	GAMEDATA in;
-	char buffer[1024];
-    QString fname;
-
-    // Get the name of the file to load
-    KUrl url = KFileDialog::getOpenUrl( KUrl(), "*.kmgame", this, i18n("Load Game" ) );
-
-    if ( url.isEmpty() )
-	return;
-
-    KIO::NetAccess::download( url, fname, this );
-
-    // open the file for reading
-    FILE *outFile = fopen( QFile::encodeName(fname), "r");
-    if (outFile == NULL) {
-	KMessageBox::sorry(this,
-		i18n("Could not read from file. Aborting."));
-	return;
-    }
-
-    // verify the magic
-    fscanf(outFile, "%1023s\n", buffer);
-    if (strcmp(buffer, gameMagic) != 0) {
-	KMessageBox::sorry(this,
-		i18n("File format not recognized."));
-	fclose(outFile);
-	return;
-    }
-
-    //ed the elapsed time
-    fscanf(outFile, "%1023s\n", buffer);
-    gameTimer->fromString(buffer);
-
-    // suck out all the game data
-    fread(&in, sizeof(GAMEDATA), 1, outFile);
-    memcpy(&bw->Game, &in, sizeof(GAMEDATA));
-
-    // close the file before exit
-    fclose(outFile);
-
-    KIO::NetAccess::removeTempFile( fname );*/
-
-    // refresh the board
-    bw->gameLoaded();
-}
+}*/
 
 void KMahjongg::restartGame() {
     if( ! bDemoModeActive ) {
@@ -625,41 +478,123 @@ void KMahjongg::restartGame() {
     }
 }
 
+
+
+void KMahjongg::loadGame() {
+  QString fname;
+
+    // Get the name of the file to load
+  KUrl url = KFileDialog::getOpenUrl( KUrl(), "*.kmgame", this, i18n("Load Game" ) );
+
+  if ( url.isEmpty() ) {
+    return;
+  }
+  
+  KIO::NetAccess::download( url, fname, this );
+
+    // open the file for reading
+  QFile infile(QFile::encodeName(fname));
+  if (!infile.open(QIODevice::ReadOnly)) {
+    KMessageBox::sorry(this,
+    i18n("Could not read from file. Aborting."));
+    return;
+  }
+  QDataStream in(&infile);
+    // verify the magic
+  QString magic;
+  in >> magic;
+
+  if (QString::compare(magic, gameMagic, Qt::CaseSensitive)!=0) {
+    KMessageBox::sorry(this,
+                       i18n("File is not a KMahjongg game."));
+    infile.close();
+    return;
+  }
+  
+  // Read the version
+  qint32 version;
+  in >> version;
+
+  if (version == gameDataVersion) {
+    in.setVersion(QDataStream::Qt_4_0);
+  } else {
+    KMessageBox::sorry(this,
+                       i18n("File format not recognized."));
+    infile.close();
+    return;
+  }
+  
+  QString theTilesName;
+  QString theBackgroundName;
+  QString theBoardLayoutName;
+  in >> theTilesName;
+  bw->loadTileset(theTilesName);
+  in >> theBackgroundName;
+  bw->loadBackground(theBackgroundName, false);
+  in >> theBoardLayoutName;
+  
+  //GameTime
+  uint seconds;
+  in >> seconds;
+  gameTimer->setTime(seconds);
+
+  delete bw->Game;
+  bw->loadBoardLayout(theBoardLayoutName);
+  bw->Game = new GameData(bw->theBoardLayout.board());
+  bw->Game->loadFromStream(in);
+
+  infile.close();
+
+  KIO::NetAccess::removeTempFile( fname );
+
+    // refresh the board
+  bw->gameLoaded();
+}
+
 void KMahjongg::saveGame() {
-//TODO adapt to new GameData class
-/*
-    // Get the name of the file to save
+  //Pause timer
+  gameTimer->pause();
+
+   // Get the name of the file to save
     KUrl url = KFileDialog::getSaveUrl( KUrl(), "*.kmgame", this, i18n("Save Game" ) );
 
-    if ( url.isEmpty() )
-	return;
+    if ( url.isEmpty() ) {
+      gameTimer->resume();
+      return;
+    }
 
    if( !url.isLocalFile() )
    {
       KMessageBox::sorry( this, i18n( "Only saving to local files currently supported." ) );
+      gameTimer->resume();
       return;
    }
+   
+   QFile outfile(QFile::encodeName(url.path()));
+   if (!outfile.open(QIODevice::WriteOnly)) {
+     KMessageBox::sorry(this,
+                        i18n("Could not write saved game."));
+     gameTimer->resume();
+     return;
+   }
+   QDataStream out(&outfile);
 
-    FILE *outFile = fopen( QFile::encodeName(url.path()), "w");
-    if (outFile == NULL) {
-	KMessageBox::sorry(this,
-		i18n("Could not write to file. Aborting."));
-	return;
-    }
+ // Write a header with a "magic number" and a version
+   out << QString(gameMagic);
+   out << (qint32) gameDataVersion;
+   out.setVersion(QDataStream::Qt_4_0);
 
-    // stick in the magic id string
-    fprintf(outFile, "%s\n", gameMagic);
+   out << bw->theTiles.path();
+   out << bw->theBackground.path();
+   out << bw->theBoardLayout.path();
 
-    // Now stick in the elapsed time for the game
-    fprintf(outFile, "%s\n", gameTimer->toString().toUtf8().constData());
-
-
-    // chuck in all the game data
-    fwrite(&bw->Game, sizeof(GAMEDATA), 1, outFile);
-
-    // close the file before exit
-    fclose(outFile);*/
+   //GameTime
+   out << gameTimer->seconds();
+ // Write the Game data
+   bw->Game->saveToStream(out);
+   
+   outfile.close();
+   gameTimer->resume();
 }
 
-
 #include "kmahjongg.moc"
