@@ -17,6 +17,7 @@
 #include "vector.h"
 #include "rtti.h"
 
+class Wall;
 
 enum BallState { Rolling = 0, Stopped, Holed };
 
@@ -45,10 +46,14 @@ public:
 	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *); 
 	virtual void advance(int phase);
 	virtual void doAdvance();
+	/*
+	 * moves the ball, by the number of pixels requested (like the normal moveBy() for everything else (I know this is bad design, need to fix by changing the names of these functions and checking that the appropriate one is called)
+	 */
+	void moveByResizedDistance(double dx, double dy);
 	/*
 	 * moves the ball, automatically modifying dx and dy to take into account resizing (so the input dx and dy can use the game's base 400x400 co-ordinated system, and do not need to be modified when the game is resized)
 	 */
-	virtual void moveBy(double dx, double dy);
+	virtual void moveBy(double baseDx, double baseDy);
 	virtual void setVelocity(double vx, double vy);
 
 	virtual bool deleteable() const { return false; }
@@ -69,6 +74,7 @@ public:
 	void setFrictionMultiplier(double news) { frictionMultiplier = news; }
 	void friction();
 	void collisionDetect(double oldx, double oldy);
+	void collideWithHaloCollisions( QList< Wall* >& haloWallCollisions );
 
 	int addStroke() const { return m_addStroke; }
 	bool placeOnGround(Vector &v) { v = oldVector; return m_placeOnGround; }
@@ -88,6 +94,8 @@ public:
 	void setCollisionLock(bool yes) { m_collisionLock = yes; }
 	virtual void fastAdvanceDone() { setCollisionLock(false); }
 
+	void shotStarted() { maxBumperBounceSpeed = 8; }
+
 	void setDoDetect(bool yes) { m_doDetect = yes; }
 	bool doDetect() const { return m_doDetect; }
 
@@ -101,6 +109,9 @@ public:
 	double getBaseX() { return baseX; }
 	double getBaseY() { return baseY; }
 
+	double getMaxBumperBounceSpeed() { return maxBumperBounceSpeed; }
+	void reduceMaxBumperBounceSpeed() { if(maxBumperBounceSpeed > 0.4) maxBumperBounceSpeed -= 0.35; }
+
 public slots:
 	void update() { doAdvance(); }
 
@@ -122,6 +133,11 @@ private:
 	 */
 	double resizeFactor;
 
+	/*
+	 * the maximum speed of the ball after hitting a bumper, this will decrease ith each bounce so that the ball does not bounce against bumpers forever
+	 */
+	double maxBumperBounceSpeed;
+
 	bool m_blowUp;
 	int blowUpCount;
 	int m_addStroke;
