@@ -51,6 +51,11 @@ void FloaterGuide::moveBy(double dx, double dy)
 
 void FloaterGuide::setPoints(double xa, double ya, double xb, double yb)
 {
+	baseX1 = xa / resizeFactor;
+	baseY1 = ya / resizeFactor;
+	baseX2 = xb / resizeFactor;
+	baseY2 = yb / resizeFactor;
+
 	if (qAbs(xa - xb) > 0 || qAbs(ya - yb) > 0)
 	{
 		Wall::setPoints(xa, ya, xb, yb);
@@ -64,6 +69,17 @@ Config *FloaterGuide::config(QWidget *parent)
 	return floater->config(parent);
 }
 
+void FloaterGuide::resize(double resizeFactor)
+{
+	this->resizeFactor = resizeFactor;
+	setPoints(baseX1*resizeFactor, baseY1*resizeFactor, baseX2*resizeFactor, baseY2*resizeFactor);
+}
+
+void FloaterGuide::updateBaseResizeInfo()
+{
+	floater->updateBaseResizeInfo();
+}
+
 /////////////////////////
 
 Floater::Floater(const QRect &rect,  QGraphicsItem *parent, QGraphicsScene *scene)
@@ -111,15 +127,14 @@ void Floater::resize(double resizeFactor)
 {
 	this->resizeFactor = resizeFactor;
 	setSpeed(speed); //update speed taking into account new resizeFactor
-	wall->setPoints(baseStartX*resizeFactor, baseStartY*resizeFactor, baseEndX*resizeFactor, baseEndY*resizeFactor);
+	wall->resize( resizeFactor );
 	Bridge::resize(resizeFactor);
 }
 
 void Floater::advance(int phase)
 {
-	if (game)
-		if(game->isEditing())
-			return;
+	if (game && game->isEditing())
+		return;
 
 	if (!isEnabled())
 		return;
@@ -153,6 +168,7 @@ void Floater::reset()
 	origin = end;
 
 	setPos(origin.x(), origin.y());
+	moveBy(0, 0);
 	setSpeed(speed);
 }
 
@@ -223,7 +239,7 @@ void Floater::moveBy(double dx, double dy)
 					//((Ball *)(*it))->setState(Rolling);
 					Ball *ball = dynamic_cast<Ball *>(*it);
                                         Q_ASSERT(ball);
-					ball->moveBy(dx, dy);
+					ball->moveByResizedDistance(dx, dy);
 					if (game && /*game->hasFocus() &&*/ !game->isEditing() && game->curBall() == (Ball *)(*it))
 							game->ballMoved();
 				}
@@ -282,11 +298,6 @@ void Floater::load(KConfigGroup *cfgGroup)
 	wall->setPoints(start.x(), start.y(), end.x(), end.y());
 	wall->setPos(0, 0);
 
-	baseStartX = start.x();
-	baseStartY = start.y();
-	baseEndX = end.x();
-	baseEndY = end.y();
-
 	setSpeed(cfgGroup->readEntry("speed", -1));
 
 	doLoad(cfgGroup);
@@ -298,6 +309,11 @@ void Floater::firstMove(int x, int y)
 	firstPoint = QPoint(x, y);
 }
 
+void Floater::updateBaseResizeInfo()
+{
+	Bridge::updateBaseResizeInfo();
+}
+
 /////////////////////////
 
 FloaterConfig::FloaterConfig(Floater *floater, QWidget *parent)
