@@ -1,3 +1,26 @@
+/*
+    Copyright Russell Steffen <rsteffen@bayarea.net>
+    Copyright Stephan Zehetner <s.zehetner@nevox.org>
+    Copyright Dmitry Suzdalev <dimsuz@gmail.com>
+    Copyright Inge Wallin <inge@lysator.liu.se>
+    Copyright Pierre Ducroquet <pinaraf@gmail.com>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
+#include "gameview.h"
+
 #include <QLayout>
 #include <QLabel>
 #include <QSlider>
@@ -20,7 +43,6 @@
 #include "fleetdlg.h"
 #include "mapview.h"
 #include "mapscene.h"
-#include "gameview.h"
 
 #include "gameview.moc"
 
@@ -194,10 +216,12 @@ GameView::keyPressEvent( QKeyEvent *e )
     foreach (Planet *p, *m_gameLogic->planets()) {
         if( p->name() == planetName ) {
             if ( m_showInformations ) {
+                m_mapScene->selectPlanet(p);
                 m_mapScene->displayPlanetInfo( p );
                 m_showInformations = false;
             } else {
                 m_mapScene->displayPlanetInfo( NULL );
+                m_mapScene->selectPlanet(p);
                 planetSelected( p );
             }
             break;
@@ -670,7 +694,8 @@ GameView::nextPlayer()
 
     // Let the AI players do their stuff
     while (m_gameInProgress 
-	   && m_gameLogic->currentPlayer()->isAiPlayer()) {
+	   && m_gameLogic->currentPlayer()->isAiPlayer())
+    {
 	dynamic_cast<AIPlayer *>(m_gameLogic->currentPlayer())
 	    ->doMove(m_gameLogic);
 	m_gameLogic->nextPlayer();
