@@ -32,6 +32,7 @@
 #include <QShowEvent>
 #include <QDomDocument>
 #include <QSvgRenderer>
+#include <QDesktopWidget>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -79,7 +80,8 @@ pWidget::pWidget()
     KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
     KStandardGameAction::restart(this, SLOT(restart()), actionCollection());
     KStandardGameAction::load(this, SLOT(openGame()), actionCollection());
-    KStandardGameAction::loadRecent(this, SLOT(openGame(const KUrl&)), actionCollection())->loadEntries( KGlobal::config()->group( QString() ));
+    recent = KStandardGameAction::loadRecent(this, SLOT(openGame(const KUrl&)), actionCollection());
+    recent->loadEntries( KGlobal::config()->group( QString() ));
     KStandardGameAction::save(this, SLOT(saveGame()), actionCollection());
     KStandardGameAction::quit(this, SLOT(close()), actionCollection());
     
@@ -127,6 +129,11 @@ pWidget::pWidget()
     connect( a, SIGNAL( triggered( bool ) ), SLOT( slotPickRandom() ) );
     a->setShortcuts( KShortcut( Qt::Key_F9 ) );
 
+    a = actionCollection()->addAction("select_deck");
+    a->setText(i18n("Select Deck..."));
+    connect( a, SIGNAL( triggered( bool ) ), SLOT( slotSelectDeck() ) );
+    a->setShortcuts( KShortcut( Qt::Key_F10 ) );
+
     m_cards = new cardMap();
 
     stats = actionCollection()->addAction("game_stats");
@@ -149,7 +156,7 @@ pWidget::pWidget()
     games->setCurrentItem(game);
 
     statusBar()->insertPermanentItem( "", 1, 0 );
-    createGUI(); // QString()/*, false*/);
+    setupGUI(qApp->desktop()->availableGeometry().size()*0.7); // QString()/*, false*/);
     //KAcceleratorManager::manage(menuBar());
 
     // QTimer::singleShot( 0, this, SLOT( newGameType() ) );
@@ -234,6 +241,29 @@ void pWidget::slotPickRandom()
     cardMap::self()->triggerRescale();
 }
 
+void pWidget::slotSelectDeck()
+{
+    KSharedConfig::Ptr config = KGlobal::config();
+    KConfigGroup cs(config, settings_group);
+    QString deckName, oldDeckName, dummy;
+    deckName = oldDeckName = cs.readEntry("Theme");
+
+    int result = KCardDialog::getCardDeck(deckName, dummy, this,  true, false);
+    if (result == QDialog::Accepted) 
+    {
+        deckName = KCardDialog::cardDir(deckName);
+	if (deckName.endsWith('/')) 
+	    deckName.chop(1);
+	deckName = deckName.mid(deckName.lastIndexOf('/') + 1);
+	if (deckName != oldDeckName) {
+	    cs.writeEntry("Theme", deckName);
+
+	    cardMap::self()->updateTheme(cs);
+	    cardMap::self()->triggerRescale();
+	}
+    }
+}
+
 void pWidget::setGameCaption()
 {
     QString name = games->currentText();
