@@ -24,10 +24,9 @@
 #include "renderer.h"
 
 #include <kdebug.h>
-#include <KPixmapEffect>
 
-#include <QPainter>
-#include <QtDebug>
+#include <QtGui/QPainter>
+#include <QtCore/QtDebug>
 
 KSame::Renderer::Renderer( const QString & fileName, const QSize& backgroundSize, const QSize& elementSize, QObject *parent )
 	: QObject( parent ), m_svgRenderer( fileName ), m_backgroundSize( backgroundSize ), m_elementSize( elementSize )
