@@ -76,6 +76,10 @@
 KWin4App::KWin4App(QWidget *parent)
         : KXmlGuiWindow(parent), mView(0), mDoc(0), mMyChatDlg(0)
 {
+  // default names for players
+  (void)I18N_NOOP2("default name of first player", "Player 1");
+  (void)I18N_NOOP2("default name of second player", "Player 2");
+
   mDoc       = 0;
   mView      = 0;
   mScene     = 0;
@@ -92,37 +96,29 @@ KWin4App::KWin4App(QWidget *parent)
   #endif
   #endif
 
-  QString theme = KStandardDirs::locate("kwin4theme", "default.rc");
-  kDebug() << "theme =" << theme;
-  if (theme.isEmpty())
-  {
-    KMessageBox::error(this, i18n("Installation error: No theme file found."));
-    QTimer::singleShot(0, this,SLOT(close()));
-    return;
-  }
-
-  mThemeDirName = KGlobal::dirs()->findResourceDir("kwin4theme","default.rc");
-  kDebug() << "THEME DIR IS" << mThemeDirName;
-
   // Read theme files
-  QString themeIndex = KGlobal::dirs()->findResource("kwin4theme","index.desktop");
-  if (themeIndex.isEmpty())
+  QStringList themeList =  KGlobal::dirs()->findAllResources("kwin4theme", "*.desktop", KStandardDirs::NoDuplicates);
+  if (themeList.isEmpty())
   {
     KMessageBox::error(this, i18n("Installation error: No theme list found."));
     QTimer::singleShot(0, this,SLOT(close()));
     return;
   }
-  KConfig themeInfo( themeIndex, KConfig::OnlyLocal);
-  QStringList themeList = themeInfo.groupList();
+
+  // Read theme files
   for (int i = 0; i < themeList.size(); i++)
   {
-    KConfigGroup themeGroup(&themeInfo, themeList.at(i));
-    QString name = themeGroup.readEntry("Name", QString());
-    QString file = themeGroup.readEntry("File", QString());
+    KConfig themeInfo( themeList.at(i), KConfig::OnlyLocal);
+    KConfigGroup themeGroup(&themeInfo, "Theme");
+    QString name   = themeGroup.readEntry("Name", QString());
+    QString file   = themeGroup.readEntry("File", QString());
+    bool isDefault = themeGroup.readEntry("Default", false);
+    if (mThemeDefault.isNull()) mThemeDefault = name;
+    if (isDefault) mThemeDefault = name;
     mThemeFiles[name] = file;
-    kDebug() <<  "Found theme: Name(i18n)="<<name<<" File="<<file;   
+    kDebug() <<  "Found theme("<<i<<"): " <<themeList.at(i) <<" Name(i18n)="<<name<<" File="<<file << " default="<<isDefault;   
   }
-  mThemeIndexNo =0;
+  mThemeIndexNo = themeIdxFromName(mThemeDefault);
 
 
   // Setup application
@@ -147,7 +143,7 @@ KWin4App::KWin4App(QWidget *parent)
 
   // Theme
   QString themeFile = themefileFromIdx(mThemeIndexNo);
-  kDebug() << "Load theme" << themeFile;
+  kDebug() << "Loading theme" << themeFile << " #"<<mThemeIndexNo;
   mTheme  = new ThemeManager(themeFile, this);
   if (mTheme->checkTheme() != 0)
   {
@@ -230,6 +226,20 @@ QString KWin4App::themefileFromIdx(int idx)
 }
 
 
+// Retrieve a theme idx from a theme name 
+int KWin4App::themeIdxFromName(QString name)
+{
+  QStringList list(mThemeFiles.keys());
+  list.sort();
+  for (int i=0; i < list.size(); ++i)
+  {
+    if (list[i] == name) return i;
+  }
+  kError() << "Theme index lookup failed for " << name;
+  return 0;
+}
+
+
 // This method is called from various places
 // and signals to check, uncheck and enable
 // or disable all menu items.
@@ -414,10 +424,10 @@ void KWin4App::changeAction(const char* action, bool enable)
 // Save instance-specific properties. The function is
 void KWin4App::saveProperties(KConfigGroup& grp)
 {
-  kDebug() << "SAVE PROPERTIES for GROUP" << grp.group();
+  kDebug() << "SAVE PROPERTIES for GROUP" << grp.name();
 
   // Save current game?
-  QString name = QString("current_game")+grp.group();
+  QString name = QString("current_game")+grp.name();
   QString filename = KStandardDirs::locateLocal("appdata", name);
   bool isRunning = (mDoc->gameStatus()==KGame::Run);
   if (isRunning)
@@ -439,7 +449,7 @@ void KWin4App::saveProperties(KConfigGroup& grp)
 // Read instance-specific properties.
 void KWin4App::readProperties(const KConfigGroup& grp)
 {
-  kDebug() << "READ PROPERTIES for GROUP" << grp.group();
+  kDebug() << "READ PROPERTIES for GROUP" << grp.name();
 
   QString filename = grp.readEntry("CurrentGame", QString());
   kDebug() << "Filename is" << filename;
@@ -476,8 +486,9 @@ void KWin4App::readProperties()
 
   // Program data
   KConfigGroup cfg = config->group("ProgramData");
-  mThemeIndexNo = cfg.readEntry("ThemeIndexNo", 0);
+  mThemeIndexNo = cfg.readEntry("ThemeIndexNo", themeIdxFromName(mThemeDefault));
   if (mThemeIndexNo >= mThemeFiles.size()) mThemeIndexNo = 0;
+  kDebug() << "Index = " << mThemeIndexNo << " def index=" << themeIdxFromName(mThemeDefault);
 
 
   kDebug() << "LOADED PROPERTIES";
@@ -778,8 +789,7 @@ void KWin4App::configureNetwork()
   int port=Prefs::port();
 
   // just for testing - should be non-modal
-  KGameDialog dlg(mDoc, 0, i18n("Network Configuration"), this,
-      KGameDialog::NetworkConfig, 20000, true);
+  KGameDialog dlg(mDoc, 0, i18n("Network Configuration"), this, KGameDialog::NetworkConfig, 20000, true);
   dlg.networkConfig()->setDefaultNetworkInfo(host, port);
   dlg.networkConfig()->setDiscoveryInfo("_kwin4._tcp",Prefs::gamename());
 
@@ -790,12 +800,15 @@ void KWin4App::configureNetwork()
   connect(mColorGroup, SIGNAL(clicked(int)), this, SLOT(remoteChanged(int)));
   connect(dlg.networkConfig(), SIGNAL(signalServerTypeChanged(int)), this, SLOT(serverTypeChanged(int)));
 
-  new QRadioButton(i18n("Yellow should be played by remote"), mColorGroup);
-  new QRadioButton(i18n("Red should be played by remote"), mColorGroup);
-  l->addWidget(mColorGroup);
+  QRadioButton *b1 = new QRadioButton(i18n("Yellow should be played by remote"), mColorGroup);
+  QRadioButton *b2 = new QRadioButton(i18n("Red should be played by remote"), mColorGroup);
+  l->addWidget(b1);
+  l->addWidget(b2);
+  //l->addWidget(mColorGroup);
   mColorGroup->setSelected(0);
   remoteChanged(0);
 
+  dlg.adjustSize();
   dlg.exec();// note: we don't have to check for the result - maybe a bug
 }
 
