@@ -30,6 +30,7 @@
 // KDE includes
 #include <kdebug.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 
 // Constructor for the sprite
 PixmapSprite::PixmapSprite(const QString &id, ThemeManager* theme, int no, QGraphicsScene* canvas)
@@ -170,6 +171,20 @@ void PixmapSprite::setPosition(QPointF pos)
 }
 
 
+// Store the logical board coordinates for theme changes
+void PixmapSprite::setLogicalPos(QPoint pos)
+{
+  mLPos = pos;
+}
+
+
+// Retrieve the logical board coordinates for theme changes
+QPoint PixmapSprite::logicalPos()
+{
+  return mLPos;
+}
+
+
 // Start or stop a frame animation
 void PixmapSprite::setAnimation(bool status)
 {
@@ -217,11 +232,12 @@ void PixmapSprite::advance(int phase)
   // Handle animation
   if (mAnimationState == Animated)
   {
-  	// Frame delay passed?
+    // Frame delay passed?
     int frame = mTime.elapsed() / mDelay + mEndFrame;
-    while(frame > mEndFrame) {
-	    frame -= (mEndFrame - mStartFrame);
-	    mTime.addSecs( -(mEndFrame - mStartFrame)*mDelay);
+    while(frame > mEndFrame)
+    {
+      frame -= (mEndFrame - mStartFrame);
+      mTime.addSecs( -(mEndFrame - mStartFrame)*mDelay);
     }
     setFrame(frame);
   }
