@@ -20,10 +20,8 @@
 #ifndef __KMESSAGESERVER_H__
 #define __KMESSAGESERVER_H__
 
-#include <QObject>
-#include <q3serversocket.h>
-#include <QString>
-
+#include <QtCore/QObject>
+#include <QtCore/QString>
 
 class KMessageIO;
 class KMessageServerPrivate;
@@ -170,7 +168,6 @@ class KMessageServerPrivate;
 
 
   @author Andreas Beckermann <b_mann@gmx.de>, Burkhard Lehner <Burkhard.Lehner@gmx.de>
-  @version $Id: kmessageserver.h 574459 2006-08-19 03:51:57Z jlee $
 */
 class KMessageServer : public QObject
 {
@@ -208,7 +205,7 @@ public:
     /**
      * Create a KGameNetwork object
      **/
-    KMessageServer(quint16 cookie = 42, QObject* parent = 0);
+    explicit KMessageServer(quint16 cookie = 42, QObject* parent = 0);
 
     ~KMessageServer();
 
@@ -251,7 +248,7 @@ public:
 
 //---------------------------------- adding / removing clients
 
-public slots:
+public Q_SLOTS:
     /**
      * Adds a new @ref KMessageIO object to the communication server. This "client"
      * gets a unique ID.
@@ -285,7 +282,7 @@ public slots:
     */
     void deleteClients();
 
-private slots:
+private Q_SLOTS:
     /**
      * Removes the sender object of the signal that called this slot. It is
      * automatically connected to @ref KMessageIO::connectionBroken.
@@ -396,7 +393,7 @@ public:
      **/
     virtual void sendMessage (const QList <quint32> &ids, const QByteArray &msg);
 
-protected slots:
+protected Q_SLOTS:
     /**
      * This slot receives all the messages from the @ref KMessageIO::received signals.
      * It stores the messages in a queue. The messages are later taken out of the queue
@@ -420,7 +417,7 @@ protected slots:
 
 //---------------------------- Signals
 
-signals:
+Q_SIGNALS:
     /**
      * A new client connected to the game
      * @param client the client object that connected
@@ -463,30 +460,4 @@ private:
 };
 
 
-/**
-  Internal class of KMessageServer. Creates a server socket and waits for
-  connections.
-
-  NOTE: This has to be here in the header file, because it is a subclass from
-  QObject and has to go through the moc.
-
-  @short An internal class for KServerSocket
-  @author Burkhard Lehner <Burkhard.Lehner@gmx.de>
-*/
-class KMessageServerSocket : public Q3ServerSocket
-{
-  Q_OBJECT
-
-public:
-  KMessageServerSocket (quint16 port, QObject *parent = 0);
-  ~KMessageServerSocket ();
-
-  void newConnection (int socket);
-
-signals:
-  void newClientConnected (KMessageIO *client);
-};
-
-
-
 #endif
