@@ -95,29 +95,30 @@ Mainwindow::Mainwindow(QWidget* parent)
   #endif
   #endif
 
-  // Theme file
-  mThemeDirName = KGlobal::dirs()->findResourceDir("lskattheme","default.rc");
-  kDebug() << "THEME DIR IS" << mThemeDirName;
-
   // Read theme files
-  QString themeIndex = KGlobal::dirs()->findResource("lskattheme","index.desktop");
-  if (themeIndex.isEmpty())
+  QStringList themeList =  KGlobal::dirs()->findAllResources("lskattheme", "*.desktop", KStandardDirs::NoDuplicates);
+  if (themeList.isEmpty())
   {
     KMessageBox::error(this, i18n("Installation error: No theme list found."));
     QTimer::singleShot(0, this,SLOT(close()));
     return;
   }
-  KConfig themeInfo( themeIndex, KConfig::OnlyLocal);
-  QStringList themeList = themeInfo.groupList();
+
+  // Read theme files
   for (int i = 0; i < themeList.size(); i++)
   {
-    KConfigGroup themeGroup(&themeInfo, themeList.at(i));
+    KConfig themeInfo( themeList.at(i), KConfig::OnlyLocal);
+    KConfigGroup themeGroup(&themeInfo, "Theme");
     QString name = themeGroup.readEntry("Name", QString());
     QString file = themeGroup.readEntry("File", QString());
+    bool isDefault = themeGroup.readEntry("Default", false);
     mThemeFiles[name] = file;
-    kDebug() <<  "Found theme: Name(i18n)="<<name<<" File="<<file;   
+    if (mThemeDefault.isNull()) mThemeDefault = name;
+    if (isDefault) mThemeDefault = name;
+
+    if (global_debug>0) kDebug() <<  "Found theme: " <<themeList.at(i) <<" Name(i18n)="<<name<<" File="<<file << " default="<<isDefault; 
   }
-  mThemeIndexNo =0;
+  mThemeIndexNo = themeIdxFromName(mThemeDefault);
 
   // Create menus etc
   initGUI();
@@ -132,7 +133,7 @@ Mainwindow::Mainwindow(QWidget* parent)
   readProperties();
 
   // TODO: Bugfix: Needs to be here if initGUI is befure readProperties
-  kDebug() << "Setting current theme item to" << mThemeIndexNo;
+  if (global_debug>0) kDebug() << "Setting current theme item to" << mThemeIndexNo;
   ((KSelectAction*)ACTION("theme"))->setCurrentItem(mThemeIndexNo);
 
 
@@ -143,8 +144,10 @@ Mainwindow::Mainwindow(QWidget* parent)
 
   // Theme manager
   QString themeFile = themefileFromIdx(mThemeIndexNo);
-  kDebug() << "Load theme" << themeFile << " no=" << mThemeIndexNo;
-  mTheme  = new ThemeManager(mCardDir, mDeckGrafix, KCardDialog::deckSVGFilePath(mDeckGrafix), 
+  if (global_debug > 0) kDebug() << "Load theme" << themeFile << " no=" << mThemeIndexNo;
+  mTheme  = new ThemeManager(KCardDialog::cardDir(mCardDir), 
+                             KCardDialog::deckFilename(mDeckGrafix),
+                             KCardDialog::deckSVGFilePath(mDeckGrafix), 
                              themeFile, this, this->width());
   if (mTheme->checkTheme() != 0)
   {
@@ -226,6 +229,18 @@ QString Mainwindow::themefileFromIdx(int idx)
   return themeFile;
 }
 
+// Retrieve a theme idx from a theme name 
+int Mainwindow::themeIdxFromName(QString name)
+{
+  QStringList list(mThemeFiles.keys());
+  list.sort();
+  for (int i=0; i < list.size(); ++i)
+  {
+    if (list[i] == name) return i;
+  }
+  kError() << "Theme index lookup failed for " << name;
+  return 0;
+}
 
 
 
@@ -236,9 +251,9 @@ void Mainwindow::saveProperties()
 
   // Program data
   KConfigGroup cfg = config->group("ProgramData");
-  cfg.writePathEntry("carddir", mCardDir);
-  cfg.writePathEntry("deck",    mDeckGrafix);
-  cfg.writeEntry("startplayer", mStartPlayer);
+  cfg.writeEntry("cards",        mCardDir);
+  cfg.writeEntry("deck",         mDeckGrafix);
+  cfg.writeEntry("startplayer",  mStartPlayer);
   cfg.writeEntry("ThemeIndexNo", mThemeIndexNo);
 
   // LSkat data
@@ -256,25 +271,30 @@ void Mainwindow::readProperties()
   KConfigGroup cfg = config->group("ProgramData");
 
   // Theme number
-  mThemeIndexNo = cfg.readEntry("ThemeIndexNo", 0);
+  mThemeIndexNo = cfg.readEntry("ThemeIndexNo", themeIdxFromName(mThemeDefault));
   if (mThemeIndexNo >= mThemeFiles.size()) mThemeIndexNo = 0;
 
   // Get default card data
-  QString dcd = KCardDialog::getDefaultCardDir();
-  dcd = KGlobal::dirs()->findResourceDir("cards", dcd)+dcd;
-  QString dd = KCardDialog::getDefaultDeck();
-  dd = KGlobal::dirs()->findResourceDir("cards", dd)+dd;
-
+  QString dcd = KCardDialog::defaultCardName();
+  QString dd  = KCardDialog::defaultDeckName();
 
   // Read card path
-  mCardDir    = cfg.readPathEntry("carddir", dcd);
-  mDeckGrafix = cfg.readPathEntry("deck", dd);
+  mCardDir    = cfg.readEntry("cards", dcd);
+  mDeckGrafix = cfg.readEntry("deck", dd);
 
   // Check for path existence
-  QFile file(mDeckGrafix);
-  if (!file.exists()) mDeckGrafix = dd;
-  QDir dir(mCardDir);
-  if (!dir.exists()) mCardDir = dcd;
+  QFile file(KCardDialog::deckFilename(mDeckGrafix));
+  if (KCardDialog::deckFilename(mDeckGrafix).isNull() || !file.exists())
+  {
+    kDebug() << "Deck " << mDeckGrafix << " does not exists. Using default " << dd;
+    mDeckGrafix = dd;
+  }
+  QDir dir(KCardDialog::cardDir(mCardDir));
+  if (KCardDialog::cardDir(mCardDir).isNull() || !dir.exists())
+  {
+    kDebug() << "Card directory " << mCardDir << " does not exists. Using default " << dcd;
+    mCardDir = dcd;
+  }
 
   if (global_debug > 0)
   {
@@ -462,7 +482,7 @@ void Mainwindow::initGUI()
   actionCollection()->addAction("theme", themeAct);
   themeAct->setItems(themes);
   connect( themeAct, SIGNAL(triggered(int)), SLOT(changeTheme(int)) );
-  kDebug() << "Setting current theme item to" << mThemeIndexNo;
+  if (global_debug>0) kDebug() << "Setting current theme item to" << mThemeIndexNo;
   themeAct->setCurrentItem(mThemeIndexNo);
   themeAct->setToolTip(i18n("Changing theme..."));
   themeAct->setWhatsThis(i18n("Changing theme."));
@@ -470,6 +490,7 @@ void Mainwindow::initGUI()
   // Choose card deck
   action = actionCollection()->addAction("select_carddeck");
   action->setText(i18n("Select &Card Deck..."));
+  action->setShortcuts( KShortcut( Qt::Key_F10 ) );
   connect(action, SIGNAL(triggered(bool)), this, SLOT(menuCardDeck()));
   action->setToolTip(i18n("Configure card decks..."));
   action->setWhatsThis(i18n("Choose how the cards should look."));
@@ -495,7 +516,7 @@ void Mainwindow::changeTheme(int idx)
 {
   mThemeIndexNo = idx;
   QString themeFile = themefileFromIdx(idx);
-  kDebug() << "Select theme" << themeFile;
+  if (global_debug>0) kDebug() << "Select theme" << themeFile;
   mTheme->updateTheme(themeFile);
 }
 
@@ -520,28 +541,29 @@ void Mainwindow::menuPlayer2By()
 // Choose a card deck
 void Mainwindow::menuCardDeck()
 {
-  QString s1,s2;
+  QString front,back;
   int result;
 
-  KCardDialog::CardFlags flags = KCardDialog::CardFlags(KCardDialog::Both|KCardDialog::SVGCards);
-  result=KCardDialog::getCardDeck(s1,s2, this, flags);
+  result=KCardDialog::getCardDeck(front, back, this, true, true, false, false);
   if (result==QDialog::Accepted)
   {
-    if (global_debug > 0) kDebug() << "NEW CARDDECK:" << s1 << "and" << s2;
+    if (global_debug > 0) kDebug() << "NEW CARDDECK:" << front << "and" << back;
     bool change = false; // Avoid unnecessary changes
-    if (!s1.isEmpty() && s1 != mDeckGrafix)
+    if (!back.isEmpty() && back != mDeckGrafix)
     {
-      mDeckGrafix = s1;
+      mDeckGrafix = back;
       change = true;
     }
-    if (!s2.isEmpty() && s2 != mCardDir)
+    if (!front.isEmpty() && front != mCardDir)
     {
-      mCardDir    = s2;
+      mCardDir    = front;
       change = true;
     }
     if (change)
     {
-      mTheme->updateCardTheme(mCardDir, mDeckGrafix, KCardDialog::deckSVGFilePath(mDeckGrafix));
+      mTheme->updateCardTheme(KCardDialog::cardDir(mCardDir), 
+                              KCardDialog::deckFilename(mDeckGrafix),
+                              KCardDialog::deckSVGFilePath(mDeckGrafix));
       mView->update(); // Be on the safe side and update
     }
   }
@@ -585,8 +607,6 @@ void Mainwindow::menuEndGame()
 // Start a new game
 void Mainwindow::menuNewLSkatGame()
 {
-  kDebug() << "Mainwindow::menuNewLSkatGame()";
-
   Player* p1 = mLSkatConfig->player(0);
   Player* p2 = mLSkatConfig->player(1);
 
